@@ -1,11 +1,13 @@
 package MooseX::SimpleConfig;
+# git description: v0.10-12-gf8c77cf
+$MooseX::SimpleConfig::VERSION = '0.11';
+# ABSTRACT: A Moose role for setting attributes from a simple configuration file
+# KEYWORDS: moose extension command line options attributes configuration file
 
 use Moose::Role;
 with 'MooseX::ConfigFromFile';
 
-our $VERSION   = '0.09';
-
-use Config::Any ();
+use Config::Any 0.13 ();
 
 sub get_config_from_file {
     my ($class, $file) = @_;
@@ -48,9 +50,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::SimpleConfig - A Moose role for setting attributes from a simple configfile
+MooseX::SimpleConfig - A Moose role for setting attributes from a simple configuration file
+
+=head1 VERSION
+
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -105,23 +113,34 @@ MooseX::SimpleConfig - A Moose role for setting attributes from a simple configf
 
 =head1 DESCRIPTION
 
-This role loads simple configfiles to set object attributes.  It
+This role loads simple files to set object attributes.  It
 is based on the abstract role L<MooseX::ConfigFromFile>, and uses
-L<Config::Any> to load your configfile.  L<Config::Any> will in
+L<Config::Any> to load your configuration file.  L<Config::Any> will in
 turn support any of a variety of different config formats, detected
 by the file extension.  See L<Config::Any> for more details about
 supported formats.
 
-Like all L<MooseX::ConfigFromFile> -derived configfile loaders, this
+To pass additional arguments to L<Config::Any> you must provide a
+C<config_any_args()> method, for example:
+
+  sub config_any_args {
+    return {
+      driver_args => { General => { '-InterPolateVars' => 1 } }
+    };
+  }
+
+Like all L<MooseX::ConfigFromFile> -derived file loaders, this
 module is automatically supported by the L<MooseX::Getopt> role as
-well, which allows specifying C<-configfile> on the commandline.
+well, which allows specifying C<-configfile> on the command line.
 
 =head1 ATTRIBUTES
 
+=for stopwords configfile
+
 =head2 configfile
 
 Provided by the base role L<MooseX::ConfigFromFile>.  You can
-provide a default configfile pathname like so:
+provide a default configuration file pathname like so:
 
   has '+configfile' => ( default => '/etc/myapp.yaml' );
 
@@ -138,8 +157,8 @@ Config files are trivially merged at the top level, with the right-hand files ta
 
 Provided by the base role L<MooseX::ConfigFromFile>.  Acts just like
 regular C<new()>, but also accepts an argument C<configfile> to specify
-the configfile from which to load other attributes.  Explicit arguments
-to C<new_with_config> will override anything loaded from the configfile.
+the file from which to load other attributes.  Explicit arguments
+to C<new_with_config> will override anything loaded from the file.
 
 =head2 get_config_from_file
 
@@ -148,11 +167,57 @@ C<new_with_options>.  Invokes L<Config::Any> to parse C<configfile>.
 
 =head1 AUTHOR
 
-Brandon L. Black, E<lt>blblack@gmail.comE<gt>
+Brandon L. Black <blblack@gmail.com>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This software is copyright (c) 2007 by Brandon L. Black <blblack@gmail.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Tomas Doran Brandon L Black Alexander Hartmaier lestrrat Сергей Романов Yuval Kogman Zbigniew Lukasiak Alex Howarth
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=item *
+
+Brandon L Black <blblack@gmail.com>
+
+=item *
+
+Alexander Hartmaier <alex.hartmaier@gmail.com>
+
+=item *
+
+lestrrat <lestrrat+github@gmail.com>
+
+=item *
+
+Сергей Романов <sromanov@cpan.org>
+
+=item *
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=item *
+
+Zbigniew Lukasiak <zby@cpan.org>
+
+=item *
+
+Alex Howarth <alex.howarth@gmail.com>
+
+=back
 
 =cut
