@@ -8,7 +8,6 @@ no Moose;
 
 package MXDefaultConfigTest;
 use Moose;
-use Path::Class::File;
 extends 'MXDefaultConfigTestBase';
 with 'MooseX::SimpleConfig';
 
@@ -16,7 +15,7 @@ has 'direct_attr' => (is => 'ro', isa => 'Int');
 
 has 'req_attr' => (is => 'rw', isa => 'Str', required => 1);
 
-has '+configfile' => ( default => 'test.yaml' );
+around 'configfile' => sub { 'test.yaml' };
 
 no Moose;
 1;
